.. include:: ../BADGES.rst

.. _wdmtoolbox_documentation:   

wdmtoolbox
==========

This is the home page for 'wdmtoolbox'.  'wdmtoolbox' is a command line
program and Python library to work with Watershed Data Management (WDM) files
used to store input and output time-series data for the Hydrological
Simulation Program - FORTRAN (HSPF) and Better Assessment Science Integrating
point and Non-point Sources (BASINS).

'wdmtoolbox' will work with Python 2.7+ and 3.3+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   install
   usage
   function_summary
   contributing
   authors
   license

API
---
.. toctree::
   :maxdepth: 2


Other Projects
--------------
http://timcera.bitbucket.io

